# Generated by Django 4.1.6 on 2023-02-20 22:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0083_workflowcontenttype"),
        ("cjkcms", "0005_layoutsettings_custom_font_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="analyticssettings",
            name="consent_modal_layout",
            field=models.CharField(
                choices=[("box", "Box"), ("cloud", "Cloud"), ("bar", "Bar")],
                default="cloud",
                help_text="Layout of the cookie consent modal",
                max_length=6,
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="contact_page",
            field=models.ForeignKey(
                blank=True,
                help_text="Show [More info] section with link to selected contact page in cookie consent settings.",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="wagtailcore.page",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="cookie_consent",
            field=models.BooleanField(
                default=False,
                help_text="Enable simple GDPR compliant cookie consent banner. Intended as a quick solution for sites that don't need a fully customisable consent.",
                verbose_name="Enable cookie consent",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="cookie_consent_deny_btn",
            field=models.BooleanField(
                default=False,
                help_text="Show an [Accept Necessary Only] button in the cookie consent banner. If unchecked, the banner will only have an accept and settings buttons.",
                verbose_name="Show Accept Necessary",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="privacy_page",
            field=models.ForeignKey(
                blank=True,
                help_text="Show a link to selected privacy policy page in cookie consent settings.",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="wagtailcore.page",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="settings_modal_layout",
            field=models.CharField(
                choices=[("box", "Box"), ("bar", "Bar")],
                default="box",
                help_text="Layout of the full cookie consent settings modal.",
                max_length=6,
            ),
        ),
    ]
