/* Font sizes and inputs */

code,
pre,
textarea.monospace,
.monospace textarea {
    font-family: var(--w-font-mono);
    font-weight: normal;
}

.input input[type='color'] {
    height: 40px;
    padding: 5px;
}


/* Show the site's custom logo in the wagtail admin */

.cjkcms-logo-custom {
    width: auto;
    height: auto;
    max-height: 80px;
    max-width: 100%;
    display: block;
}

.cjkcms-logo-container {
    box-sizing: border-box;
    margin: 0 15px;
}

.cjkcms-logo-container.navbar-light {
    background-color: #fff;
    border-radius: 6px;
    padding: 0.25em;
}

.cjkcms-logo-container.navbar-dark {
    background-color: transparent;
}


/* Display the optional banner above main content */

.cjkcms-banner {
    position: absolute;
    z-index: 1;
}

.cjkcms-banner~.content-wrapper {
    padding-top: calc(1.5em + 8px);
}