{% block block_render %}
    <blockquote class="blockquote {{self.settings.custom_css_class}}"
    {% if self.settings.custom_id %}id="{{self.settings.custom_id}}"{% endif %}>
        <p class="mb-0">{{self.text}}</p>
        {% if self.author %}<footer class="blockquote-footer mt-1">{{self.author}}</footer>{% endif %}
    </blockquote>
{% endblock %}