{% extends "cjkcms/blocks/base_block.html" %}
{% load wagtailcore_tags %}

{% block block_render %}
    <h3>{% include_block self.heading %}</h3>
    {% for item in self.items %}
        {% include_block item %}
    {% endfor %}
{% endblock %}
