{% extends 'cjkcms/blocks/base_block.html' %}
{% load wagtailcore_tags wagtailimages_tags %}

{% block block_render %}

    <div class="card-group">
        {% for page in pages %}
        {% with page.specific as article %}
            {% include "cjkcms/blocks/article_block_card.html" %}
        {% endwith %}
        {% endfor %}
    </div>

{% endblock %}
