{% load wagtailimages_tags %}

{% image self.image max-1000x1000 as self_image %}

<img src="{{self_image.url}}"
class="w-100 {{self.settings.custom_css_class}}"
{% if self.settings.custom_id %}id="{{self.settings.custom_id}}"{% endif %}
alt="{{self_image.image.title}}" />

